==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/kn.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "Saved" : "﻿ಉಳಿಸಿದ",
    "No user supplied" : "﻿ಯಾವುದೇ ಬಳಕೆದಾರನ ಹೆಸರನ್ನು ನೀಡಿರುವುದಿಲ್ಲ",
    "Unable to change password" : "﻿ಗುಪ್ತಪದವನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Authentication error" : "ದೃಢೀಕರಣ ದೋಷ",
    "Group already exists." : "﻿ಗುಂಪು ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ.",
    "Unable to add group." : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.",
    "Unable to delete group." : "﻿ಗುಂಪುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "You need to set your user email before being able to send test emails." : "ನೀವು ಪರೀಕ್ಷಾ ಇ-ಅಂಚೆಯನ್ನು ಕಳುಹಿಸುವ ಮುನ್ನ ನಿಮ್ಮ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು  ಹೊಂದಿಸಬೇಕಾಗುತ್ತದೆ.",
    "Invalid request" : "﻿ಅಮಾನ್ಯ ಕೋರಿಕೆ",
    "Invalid mail address" : "﻿ಅಮಾನ್ಯ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Unable to create user." : "﻿ಬಳಕೆದಾರನ ಖಾತೆ ರಚಿಸಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.",
    "Unable to delete user." : "ಬಳಕೆದಾರನ ಹೆಸರುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "Unable to change full name" : "﻿ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ",
    "Your full name has been changed." : "﻿ನಿಮ್ಮ ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲಾಗಿದೆ.",
    "Forbidden" : "ನಿರ್ಬಂಧಿಸಲಾಗಿದೆ",
    "Invalid user" : "﻿ಅಮಾನ್ಯ ಬಳಕೆದಾರ",
    "Unable to change mail address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Email saved" : "ಇ-ಅಂಚೆಯನ್ನು ﻿ಉಳಿಸಿದೆ",
    "Your %s account was created" : "﻿ನಿಮ್ಮ%s ಖಾತೆಯನ್ನು ಸ್ಥಾಪಿಸಲಾಗಿದೆ",
    "Couldn't remove app." : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Couldn't update app." : "﻿ ಕಾಯಕ್ರಮವನ್ನು ನವೀಕರಿಸಲ ಸಾದ್ಯವಾಗುತ್ತಿಲ್ಲ.",
    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
    "All" : "﻿ಎಲ್ಲಾ",
    "Error while disabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Disable" : "﻿ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಿ",
    "Enable" : "ಸಕ್ರಿಯಗೊಳಿಸು",
    "Error while enabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updating...." : "ಆಧುನೀಕರಿಸುಲಾಗುತ್ತಿದೇ ....",
    "Error while updating app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು  ನವೀಕರಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updated" : "ಆಧುನೀಕರಿಸಲಾಗಿದೆ",
    "Valid until {date}" : "﻿{date} ವರೆಗೆ ಚಾಲ್ತಿಯಲ್ಲಿರುತ್ತದೆ",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Select a profile picture" : "ಸಂಕ್ಷಿಪ್ತ ವ್ಯಕ್ತಿಚಿತ್ರ ಒಂದನ್ನು ಆಯ್ಕೆ ಮಾಡಿ",
    "Very weak password" : "ಅತೀ ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "Weak password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "So-so password" : "ಊಹಿಸಬಹುದಾದ ಗುಪ್ತಪದ",
    "Good password" : "ಉತ್ತಮ ಗುಪ್ತಪದ",
    "Strong password" : "﻿ಪ್ರಬಲ ಗುಪ್ತಪದ",
    "Groups" : "﻿ಗುಂಪುಗಳು",
    "Unable to delete {objName}" : "﻿{objName} ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ ",
    "A valid group name must be provided" : "ಮಾನ್ಯ ಗುಂಪಿನ ಹೆಸರನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "deleted {groupName}" : "﻿ಅಳಿಸಲಾಗಿದೆ {groupName}",
    "undo" : "ಹಿಂದಿರುಗಿಸು",
    "never" : "﻿ಎಂದಿಗೂ",
    "deleted {userName}" : "{userName} ಬಳಕೆಯ ಹೆಸರುನ್ನು  ﻿ಅಳಿಸಲಾಗಿದೆ ﻿",
    "A valid username must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಹೆಸರು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "A valid password must be provided" : "ಸರಿಯಾದ ಬಳಕೆದಾರ ಗುಪ್ತಪದ ಒದಗಿಸಬೇಕಾಗಿದೆ",
    "A valid email must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "__language_name__" : "ಕನ್ನಡ",
    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ",
    "Login" : "ಖಾತೆ ಪ್ರವೇಶಿಸು",
    "Plain" : "﻿ಸರಳ",
    "Send mode" : "ಕಳುಹಿಸುವ ﻿ಕ್ರಮ",
    "Encryption" : "ರಹಸ್ಯ ಸಂಕೇತೀಕರಿಸು",
    "mail" : "﻿ಅಂಚೆ",
    "Authentication method" : "﻿ದೃಢೀಕರಣ ವಿಧಾನ",
    "Authentication required" : "﻿ದೃಢೀಕರಣ ಅಗತ್ಯವಿದೆ",
    "Server address" : "﻿ಪರಿಚಾರಕ ಗಣಕಯಂತ್ರದ ವಿಳಾಸ",
    "Port" : "﻿ರೇವು",
    "Credentials" : "﻿ರುಜುವಾತುಗಳು",
    "SMTP Username" : "﻿SMTP ಬಳಕೆದಾರ ಹೆಸರು",
    "SMTP Password" : "﻿SMTP ಗುಪ್ತ ಪದ",
    "Test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
    "Version" : "﻿ಆವೃತ್ತಿ",
    "Sharing" : "﻿ಹಂಚಿಕೆ",
    "Expire after " : "ನಿಶ್ವಸಿಸುವ ಅವಧಿ",
    "days" : "﻿ದಿನಗಳು",
    "Enforce expiration date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಬಲವ೦ತವಾಗಿ ಜಾರಿಗೆ ಮಾಡಿ",
    "Documentation:" : "﻿ದಾಖಲೆ:",
    "Enable only for specific groups" : "﻿ಕೇವಲ ನಿರ್ದಿಷ್ಟ ಗುಂಪುಗಳಿಗೆ ಸಕ್ರಿಯಗೊಳಿಸಿ",
    "Forum" : "﻿ವೇದಿಕೆ",
    "Cancel" : "﻿ರದ್ದು",
    "Email" : "﻿ಇ-ಅಂಚೆ",
    "Your email address" : "﻿ನಿಮ್ಮ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Password" : "ಗುಪ್ತ ಪದ",
    "Current password" : "ಪ್ರಸ್ತುತ ಗುಪ್ತಪದ",
    "New password" : "﻿ಹೊಸ ಗುಪ್ತಪದ",
    "Change password" : "ಗುಪ್ತ ಪದವನ್ನು ಬದಲಾಯಿಸಿ",
    "Language" : "﻿ಭಾಷೆ",
    "Help translate" : "﻿ಭಾಷಾಂತರಿಸಲು ಸಹಾಯ ಮಾಡಿ",
    "Name" : "﻿ಹೆಸರು",
    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
    "E-Mail" : "ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Create" : "ಸೃಷ್ಟಿಸಿ",
    "Everyone" : "﻿ಪ್ರತಿಯೊಬ್ಬರೂ",
    "Admins" : "﻿ನಿರ್ವಾಹಕರು",
    "Other" : "﻿ಇತರೆ",
    "Quota" : "ಪಾಲು",
    "change full name" : "﻿ಪೂರ್ಣ ಹೆಸರು ಬದಲಾಯಿಸಬಹುದು",
    "set new password" : "﻿ಹೊಸ ಗುಪ್ತಪದವನ್ನು ಹೊಂದಿಸಿ",
    "change email address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಿ",
    "Default" : "ಆರಂಭದ ಪ್ರತಿ",
    "Enabled" : "ಸಕ್ರಿಯಗೊಳಿಸಿದೆ",
    "Not enabled" : "﻿ಸಕ್ರಿಯಗೊಳಿಸಿಲ್ಲ",
    "test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Admins can't remove themself from the admin group" : "﻿ನಿರ್ವಾಹಕರು ನಿರ್ವಹಣೆ ಗುಂಪಿನಿಂದ ತಮ್ಮನ್ನೇ ತಾವು ತೆಗೆದುಹಾಕಿಕೊಳ್ಳಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Unable to add user to group %s" : "%s ಗುಂಪಿಗೆ ಹೂಸ ಬಳಕೆದಾರನನ್ನು ಸೇರಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Unable to remove user from group %s" : "%s ಗುಂಪು ಬಳಕೆದಾರ ತೆಗೆದುಹಾಕಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ",
    "Sending..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
    "Uninstalling ...." : "ಅಳಿಸಿಹಾಕುವುದು ...",
    "Error while uninstalling app" : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Uninstall" : "ಅಳಿಸಿ",
    "Cheers!" : "ಆನಂದಿಸಿ !"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/kn.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "Saved" : "﻿ಉಳಿಸಿದ",
    "No user supplied" : "﻿ಯಾವುದೇ ಬಳಕೆದಾರನ ಹೆಸರನ್ನು ನೀಡಿರುವುದಿಲ್ಲ",
    "Unable to change password" : "﻿ಗುಪ್ತಪದವನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Authentication error" : "ದೃಢೀಕರಣ ದೋಷ",
    "Group already exists." : "﻿ಗುಂಪು ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ.",
    "Unable to add group." : "﻿ಗುಂಪುನ್ನು ಸೇರಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.",
    "Unable to delete group." : "﻿ಗುಂಪುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "You need to set your user email before being able to send test emails." : "ನೀವು ಪರೀಕ್ಷಾ ಇ-ಅಂಚೆಯನ್ನು ಕಳುಹಿಸುವ ಮುನ್ನ ನಿಮ್ಮ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು  ಹೊಂದಿಸಬೇಕಾಗುತ್ತದೆ.",
    "Invalid mail address" : "﻿ಅಮಾನ್ಯ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Unable to create user." : "﻿ಬಳಕೆದಾರನ ಖಾತೆ ರಚಿಸಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.",
    "Unable to delete user." : "ಬಳಕೆದಾರನ ಹೆಸರುನ್ನು ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ.",
    "Unable to change full name" : "﻿ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ",
    "Your full name has been changed." : "﻿ನಿಮ್ಮ ಪೂರ್ಣ ಹೆಸರನ್ನು ಬದಲಾಯಿಸಲಾಗಿದೆ.",
    "Forbidden" : "ನಿರ್ಬಂಧಿಸಲಾಗಿದೆ",
    "Invalid user" : "﻿ಅಮಾನ್ಯ ಬಳಕೆದಾರ",
    "Unable to change mail address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Email saved" : "ಇ-ಅಂಚೆಯನ್ನು ﻿ಉಳಿಸಿದೆ",
    "Your %s account was created" : "﻿ನಿಮ್ಮ%s ಖಾತೆಯನ್ನು ಸ್ಥಾಪಿಸಲಾಗಿದೆ",
    "Couldn't remove app." : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Couldn't update app." : "﻿ ಕಾಯಕ್ರಮವನ್ನು ನವೀಕರಿಸಲ ಸಾದ್ಯವಾಗುತ್ತಿಲ್ಲ.",
    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
    "All" : "﻿ಎಲ್ಲಾ",
    "Error while disabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Disable" : "﻿ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಿ",
    "Enable" : "ಸಕ್ರಿಯಗೊಳಿಸು",
    "Error while enabling app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updating...." : "ಆಧುನೀಕರಿಸುಲಾಗುತ್ತಿದೇ ....",
    "Error while updating app" : "ಕಾರ್ಯಕ್ರಮವನ್ನು  ನವೀಕರಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Updated" : "ಆಧುನೀಕರಿಸಲಾಗಿದೆ",
    "Valid until {date}" : "﻿{date} ವರೆಗೆ ಚಾಲ್ತಿಯಲ್ಲಿರುತ್ತದೆ",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Select a profile picture" : "ಸಂಕ್ಷಿಪ್ತ ವ್ಯಕ್ತಿಚಿತ್ರ ಒಂದನ್ನು ಆಯ್ಕೆ ಮಾಡಿ",
    "Very weak password" : "ಅತೀ ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "Weak password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "So-so password" : "ಊಹಿಸಬಹುದಾದ ಗುಪ್ತಪದ",
    "Good password" : "ಉತ್ತಮ ಗುಪ್ತಪದ",
    "Strong password" : "﻿ಪ್ರಬಲ ಗುಪ್ತಪದ",
    "Groups" : "﻿ಗುಂಪುಗಳು",
    "Unable to delete {objName}" : "﻿{objName} ಅಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ ",
    "A valid group name must be provided" : "ಮಾನ್ಯ ಗುಂಪಿನ ಹೆಸರನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "deleted {groupName}" : "﻿ಅಳಿಸಲಾಗಿದೆ {groupName}",
    "undo" : "ಹಿಂದಿರುಗಿಸು",
    "never" : "﻿ಎಂದಿಗೂ",
    "deleted {userName}" : "{userName} ಬಳಕೆಯ ಹೆಸರುನ್ನು  ﻿ಅಳಿಸಲಾಗಿದೆ ﻿",
    "A valid username must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಹೆಸರು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "A valid password must be provided" : "ಸರಿಯಾದ ಬಳಕೆದಾರ ಗುಪ್ತಪದ ಒದಗಿಸಬೇಕಾಗಿದೆ",
    "A valid email must be provided" : "﻿ಮಾನ್ಯ ಬಳಕೆದಾರ ಇ-ಅಂಚೆಯನ್ನು ಒದಗಿಸಬೇಕಾಗುತ್ತದೆ",
    "Documentation:" : "﻿ದಾಖಲೆ:",
    "Enable only for specific groups" : "﻿ಕೇವಲ ನಿರ್ದಿಷ್ಟ ಗುಂಪುಗಳಿಗೆ ಸಕ್ರಿಯಗೊಳಿಸಿ",
    "Forum" : "﻿ವೇದಿಕೆ",
    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ",
    "Login" : "ಖಾತೆ ಪ್ರವೇಶಿಸು",
    "Plain" : "﻿ಸರಳ",
    "Send mode" : "ಕಳುಹಿಸುವ ﻿ಕ್ರಮ",
    "Encryption" : "ರಹಸ್ಯ ಸಂಕೇತೀಕರಿಸು",
    "mail" : "﻿ಅಂಚೆ",
    "Authentication method" : "﻿ದೃಢೀಕರಣ ವಿಧಾನ",
    "Authentication required" : "﻿ದೃಢೀಕರಣ ಅಗತ್ಯವಿದೆ",
    "Server address" : "﻿ಪರಿಚಾರಕ ಗಣಕಯಂತ್ರದ ವಿಳಾಸ",
    "Port" : "﻿ರೇವು",
    "Credentials" : "﻿ರುಜುವಾತುಗಳು",
    "SMTP Username" : "﻿SMTP ಬಳಕೆದಾರ ಹೆಸರು",
    "SMTP Password" : "﻿SMTP ಗುಪ್ತ ಪದ",
    "Test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
    "Version" : "﻿ಆವೃತ್ತಿ",
    "Sharing" : "﻿ಹಂಚಿಕೆ",
    "Expire after " : "ನಿಶ್ವಸಿಸುವ ಅವಧಿ",
    "days" : "﻿ದಿನಗಳು",
    "Enforce expiration date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಬಲವ೦ತವಾಗಿ ಜಾರಿಗೆ ಮಾಡಿ",
    "Cancel" : "﻿ರದ್ದು",
    "Email" : "﻿ಇ-ಅಂಚೆ",
    "Your email address" : "﻿ನಿಮ್ಮ ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Language" : "﻿ಭಾಷೆ",
    "Help translate" : "﻿ಭಾಷಾಂತರಿಸಲು ಸಹಾಯ ಮಾಡಿ",
    "Password" : "ಗುಪ್ತ ಪದ",
    "Current password" : "ಪ್ರಸ್ತುತ ಗುಪ್ತಪದ",
    "New password" : "﻿ಹೊಸ ಗುಪ್ತಪದ",
    "Change password" : "ಗುಪ್ತ ಪದವನ್ನು ಬದಲಾಯಿಸಿ",
    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
    "E-Mail" : "ಇ-ಅಂಚೆ ವಿಳಾಸ",
    "Create" : "ಸೃಷ್ಟಿಸಿ",
    "Everyone" : "﻿ಪ್ರತಿಯೊಬ್ಬರೂ",
    "Admins" : "﻿ನಿರ್ವಾಹಕರು",
    "Other" : "﻿ಇತರೆ",
    "Quota" : "ಪಾಲು",
    "change full name" : "﻿ಪೂರ್ಣ ಹೆಸರು ಬದಲಾಯಿಸಬಹುದು",
    "set new password" : "﻿ಹೊಸ ಗುಪ್ತಪದವನ್ನು ಹೊಂದಿಸಿ",
    "change email address" : "﻿ಇ-ಅಂಚೆ ವಿಳಾಸ ಬದಲಾಯಿಸಿ",
    "Default" : "ಆರಂಭದ ಪ್ರತಿ",
    "Enabled" : "ಸಕ್ರಿಯಗೊಳಿಸಿದೆ",
    "Not enabled" : "﻿ಸಕ್ರಿಯಗೊಳಿಸಿಲ್ಲ",
    "test email settings" : "ಪರೀರ್ಕ್ಷಾತ ﻿ಇ-ಅಂಚೆಯ ಆಯ್ಕೇ",
    "Invalid request" : "﻿ಅಮಾನ್ಯ ಕೋರಿಕೆ",
    "Admins can't remove themself from the admin group" : "﻿ನಿರ್ವಾಹಕರು ನಿರ್ವಹಣೆ ಗುಂಪಿನಿಂದ ತಮ್ಮನ್ನೇ ತಾವು ತೆಗೆದುಹಾಕಿಕೊಳ್ಳಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Unable to add user to group %s" : "%s ಗುಂಪಿಗೆ ಹೂಸ ಬಳಕೆದಾರನನ್ನು ಸೇರಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Unable to remove user from group %s" : "%s ಗುಂಪು ಬಳಕೆದಾರ ತೆಗೆದುಹಾಕಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ",
    "Sending..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
    "Uninstalling ...." : "ಅಳಿಸಿಹಾಕುವುದು ...",
    "Error while uninstalling app" : "ಅಳಿಸುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Uninstall" : "ಅಳಿಸಿ",
    "__language_name__" : "ಕನ್ನಡ",
    "Cheers!" : "ಆನಂದಿಸಿ !",
    "Name" : "﻿ಹೆಸರು"
},
"nplurals=1; plural=0;");
